<?php
/**
 * Fashion Designer Theme Customizer
 *
 * @package Fashion Designer
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function fashion_designer_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'fashion_designer_custom_controls' );

function fashion_designer_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'fashion_designer_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'fashion_designer_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$FashionDesignerParentPanel = new Fashion_Designer_WP_Customize_Panel( $wp_customize, 'fashion_designer_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => 'VW Settings',
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'fashion_designer_left_right', array(
    	'title'      => __( 'General Settings', 'fashion-designer' ),
		'panel' => 'fashion_designer_panel_id'
	) );

	$wp_customize->add_setting('fashion_designer_width_option',array(
        'default' => __('Full Width','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control(new Fashion_Designer_Image_Radio_Control($wp_customize, 'fashion_designer_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','fashion-designer'),
        'description' => __('Here you can change the width layout of Website.','fashion-designer'),
        'section' => 'fashion_designer_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('fashion_designer_theme_options',array(
        'default' => __('Right Sidebar','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control('fashion_designer_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','fashion-designer'),
        'description' => __('Here you can change the sidebar layout for posts. ','fashion-designer'),
        'section' => 'fashion_designer_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','fashion-designer'),
            'Right Sidebar' => __('Right Sidebar','fashion-designer'),
            'One Column' => __('One Column','fashion-designer'),
            'Three Columns' => __('Three Columns','fashion-designer'),
            'Four Columns' => __('Four Columns','fashion-designer'),
            'Grid Layout' => __('Grid Layout','fashion-designer')
        ),
	) );

	$wp_customize->add_setting('fashion_designer_page_layout',array(
        'default' => __('One Column','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control('fashion_designer_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','fashion-designer'),
        'description' => __('Here you can change the sidebar layout for pages. ','fashion-designer'),
        'section' => 'fashion_designer_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','fashion-designer'),
            'Right Sidebar' => __('Right Sidebar','fashion-designer'),
            'One Column' => __('One Column','fashion-designer')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'fashion_designer_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','fashion-designer' ),
		'section' => 'fashion_designer_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'fashion_designer_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','fashion-designer' ),
		'section' => 'fashion_designer_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'fashion_designer_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','fashion-designer' ),
        'section' => 'fashion_designer_left_right'
    )));

	$wp_customize->add_setting('fashion_designer_loader_icon',array(
        'default' => __('Two Way','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control('fashion_designer_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','fashion-designer'),
        'section' => 'fashion_designer_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','fashion-designer'),
            'Dots' => __('Dots','fashion-designer'),
            'Rotate' => __('Rotate','fashion-designer')
        ),
	) );

	//Top Bar
	$wp_customize->add_section( 'fashion_designer_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'fashion-designer' ),
		'panel' => 'fashion_designer_panel_id'
	) );

	//Sticky Header
	$wp_customize->add_setting( 'fashion_designer_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','fashion-designer' ),
        'section' => 'fashion_designer_topbar'
    )));

    $wp_customize->add_setting( 'fashion_designer_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','fashion-designer' ),
      	'section' => 'fashion_designer_topbar'
    )));

    $wp_customize->add_setting('fashion_designer_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_search_font_size',array(
		'label'	=> __('Search Font Size','fashion-designer'),
		'description'	=> __('Enter a value in pixels. Example:20px','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_topbar',
		'type'=> 'text'
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'fashion_designer_call', array( 
			'selector' => '.info-ctr p', 
			'render_callback' => 'fashion_designer_customize_partial_fashion_designer_call', 
	));

    $wp_customize->add_setting('fashion_designer_call_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_call_icon',array(
		'label'	=> __('Add Phone Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_topbar',
		'setting'	=> 'fashion_designer_call_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('fashion_designer_call_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_call_text',array(
		'label'	=> __('Add Phone Text','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'PHONE', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_call',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_call',array(
		'label'	=> __('Add Phone Number','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 567 890', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_email_icon',array(
		'default'	=> 'fas fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_email_icon',array(
		'label'	=> __('Add Email Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_topbar',
		'setting'	=> 'fashion_designer_email_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('fashion_designer_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_email_text',array(
		'label'	=> __('Add Email Text','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'MAIL', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_email',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_email',array(
		'label'	=> __('Add Email Address','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'example@gmail.com', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_cart_icon',array(
		'default'	=> 'fas fa-shopping-basket',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_cart_icon',array(
		'label'	=> __('Add Cart Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_topbar',
		'setting'	=> 'fashion_designer_cart_icon',
		'type'		=> 'icon'
	)));
    
	//Slider
	$wp_customize->add_section( 'fashion_designer_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'fashion-designer' ),
		'panel' => 'fashion_designer_panel_id'
	) );

	$wp_customize->add_setting( 'fashion_designer_slider_arrows',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','fashion-designer' ),
      	'section' => 'fashion_designer_slidersettings'
    )));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial(
    	'fashion_designer_slider_arrows',array(
			'selector'        => '#slider .inner_carousel h1',
			'render_callback' => 'fashion_designer_customize_partial_fashion_designer_slider_arrows',
	));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'fashion_designer_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'fashion_designer_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'fashion_designer_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'fashion-designer' ),
			'description' => __('Slider image size (1600 x 700)','fashion-designer'),
			'section'  => 'fashion_designer_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('fashion_designer_slider_content_option',array(
        'default' => __('Center','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control(new Fashion_Designer_Image_Radio_Control($wp_customize, 'fashion_designer_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','fashion-designer'),
        'section' => 'fashion_designer_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

	//Opacity
	$wp_customize->add_setting('fashion_designer_slider_opacity_color',array(
      'default'              => 0.4,
      'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));

	$wp_customize->add_control( 'fashion_designer_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','fashion-designer' ),
	'section'     => 'fashion_designer_slidersettings',
	'type'        => 'select',
	'settings'    => 'fashion_designer_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','fashion-designer'),
      '0.1' =>  esc_attr('0.1','fashion-designer'),
      '0.2' =>  esc_attr('0.2','fashion-designer'),
      '0.3' =>  esc_attr('0.3','fashion-designer'),
      '0.4' =>  esc_attr('0.4','fashion-designer'),
      '0.5' =>  esc_attr('0.5','fashion-designer'),
      '0.6' =>  esc_attr('0.6','fashion-designer'),
      '0.7' =>  esc_attr('0.7','fashion-designer'),
      '0.8' =>  esc_attr('0.8','fashion-designer'),
      '0.9' =>  esc_attr('0.9','fashion-designer')
	),
	));
 
	//Services
	$wp_customize->add_section('fashion_designer_category_section',array(
		'title'	=> __('Fashion Categroy Section','fashion-designer'),
		'panel' => 'fashion_designer_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'fashion_designer_category', array( 
		'selector' => '.box-content h2', 
		'render_callback' => 'fashion_designer_customize_partial_fashion_designer_category',
	));

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('fashion_designer_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('fashion_designer_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Latest Post','fashion-designer'),
		'description'=> __('Size of image should be 370 x 270 ','fashion-designer'),
		'section' => 'fashion_designer_category_section',
	));

	$wp_customize->add_setting('fashion_designer_category_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_category_icon',array(
		'label'	=> __('Add Category Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_category_section',
		'setting'	=> 'fashion_designer_category_icon',
		'type'		=> 'icon'
	)));

	//Blog Post
	$wp_customize->add_panel( $FashionDesignerParentPanel );

	$BlogPostParentPanel = new Fashion_Designer_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'fashion-designer' ),
		'panel' => 'fashion_designer_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'fashion_designer_post_settings', array(
		'title' => __( 'Post Settings', 'fashion-designer' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'fashion_designer_toggle_postdate', array( 
			'selector' => '.post-main-box h2 a', 
			'render_callback' => 'fashion_designer_customize_partial_fashion_designer_toggle_postdate', 
	));

	$wp_customize->add_setting( 'fashion_designer_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','fashion-designer' ),
        'section' => 'fashion_designer_post_settings'
    )));

    $wp_customize->add_setting( 'fashion_designer_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_toggle_author',array(
		'label' => esc_html__( 'Author','fashion-designer' ),
		'section' => 'fashion_designer_post_settings'
    )));

    $wp_customize->add_setting( 'fashion_designer_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_toggle_comments',array(
		'label' => esc_html__( 'Comments','fashion-designer' ),
		'section' => 'fashion_designer_post_settings'
    )));

    $wp_customize->add_setting( 'fashion_designer_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'fashion_designer_switch_sanitization'
	));
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_toggle_tags', array(
		'label' => esc_html__( 'Tags','fashion-designer' ),
		'section' => 'fashion_designer_post_settings'
    )));

    $wp_customize->add_setting( 'fashion_designer_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'fashion_designer_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','fashion-designer' ),
		'section'     => 'fashion_designer_post_settings',
		'type'        => 'range',
		'settings'    => 'fashion_designer_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('fashion_designer_blog_layout_option',array(
        'default' => __('Default','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
    ));
    $wp_customize->add_control(new Fashion_Designer_Image_Radio_Control($wp_customize, 'fashion_designer_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','fashion-designer'),
        'section' => 'fashion_designer_post_settings',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

    $wp_customize->add_setting('fashion_designer_excerpt_settings',array(
        'default' => __('Excerpt','fashion-designer'),
        'transport' => 'refresh',
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control('fashion_designer_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','fashion-designer'),
        'section' => 'fashion_designer_post_settings',
        'choices' => array(
        	'Content' => __('Content','fashion-designer'),
            'Excerpt' => __('Excerpt','fashion-designer'),
            'No Content' => __('No Content','fashion-designer')
        ),
	) );

	$wp_customize->add_setting('fashion_designer_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_post_settings',
		'type'=> 'text'
	));

    // Button Settings
	$wp_customize->add_section( 'fashion_designer_button_settings', array(
		'title' => __( 'Button Settings', 'fashion-designer' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('fashion_designer_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','fashion-designer'),
		'description'	=> __('Enter a value in pixels. Example:20px','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','fashion-designer'),
		'description'	=> __('Enter a value in pixels. Example:20px','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'fashion_designer_button_border_radius', array(
		'default'              => '',
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'fashion_designer_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','fashion-designer' ),
		'section'     => 'fashion_designer_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('fashion_designer_button_text', array( 
			'selector' => '.post-main-box .more-btn a', 
			'render_callback' => 'fashion_designer_customize_partial_fashion_designer_button_text', 
	));

	$wp_customize->add_setting('fashion_designer_button_text',array(
		'default'=> 'READ MORE',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_button_text',array(
		'label'	=> __('Add Button Text','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'READ MORE', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'fashion_designer_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'fashion-designer' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('fashion_designer_related_post_title', array( 
			'selector' => '.related-post h3', 
			'render_callback' => 'fashion_designer_customize_partial_fashion_designer_related_post_title', 
	));

    $wp_customize->add_setting( 'fashion_designer_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ) );
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_related_post',array(
		'label' => esc_html__( 'Related Post','fashion-designer' ),
		'section' => 'fashion_designer_related_posts_settings'
    )));

    $wp_customize->add_setting('fashion_designer_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_related_post_title',array(
		'label'	=> __('Add Related Post Title','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('fashion_designer_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_related_posts_count',array(
		'label'	=> __('Add Related Post Count','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_related_posts_settings',
		'type'=> 'number'
	));

    //404 Page Setting
	$wp_customize->add_section('fashion_designer_404_page',array(
		'title'	=> __('404 Page Settings','fashion-designer'),
		'panel' => 'fashion_designer_panel_id',
	));	

	$wp_customize->add_setting('fashion_designer_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('fashion_designer_404_page_title',array(
		'label'	=> __('Add Title','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('fashion_designer_404_page_content',array(
		'label'	=> __('Add Text','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('fashion_designer_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_404_page_button_text',array(
		'label'	=> __('Add Button Text','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'Go Back', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_404_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('fashion_designer_responsive_media',array(
		'title'	=> __('Responsive Media','fashion-designer'),
		'panel' => 'fashion_designer_panel_id',
	));

    $wp_customize->add_setting( 'fashion_designer_stickyheader_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_stickyheader_hide_show',array(
          'label' => esc_html__( 'Sticky Header','fashion-designer' ),
          'section' => 'fashion_designer_responsive_media'
    )));

    $wp_customize->add_setting( 'fashion_designer_resp_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_resp_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','fashion-designer' ),
          'section' => 'fashion_designer_responsive_media'
    )));

	$wp_customize->add_setting( 'fashion_designer_metabox_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_metabox_hide_show',array(
          'label' => esc_html__( 'Show / Hide Metabox','fashion-designer' ),
          'section' => 'fashion_designer_responsive_media'
    )));

    $wp_customize->add_setting( 'fashion_designer_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_sidebar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Sidebar','fashion-designer' ),
          'section' => 'fashion_designer_responsive_media'
    )));

    $wp_customize->add_setting('fashion_designer_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_responsive_media',
		'setting'	=> 'fashion_designer_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('fashion_designer_res_menu_close_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_res_menu_close_icon',array(
		'label'	=> __('Add Close Menu Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_responsive_media',
		'setting'	=> 'fashion_designer_res_menu_close_icon',
		'type'		=> 'icon'
	)));

	//Content Craetion
	$wp_customize->add_section( 'fashion_designer_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'fashion-designer' ),
		'priority' => null,
		'panel' => 'fashion_designer_panel_id'
	) );

	$wp_customize->add_setting('fashion_designer_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new Fashion_Designer_Content_Creation( $wp_customize, 'fashion_designer_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','fashion-designer' ),
		),
		'section' => 'fashion_designer_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'fashion-designer' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('fashion_designer_footer',array(
		'title'	=> __('Footer Settings','fashion-designer'),
		'panel' => 'fashion_designer_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'fashion_designer_footer_text', array( 
			'selector' => '#footer-2 .copyright p', 
		'render_callback' => 'fashion_designer_customize_partial_fashion_designer_footer_text', 
	));
	
	$wp_customize->add_setting('fashion_designer_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('fashion_designer_footer_text',array(
		'label'	=> __('Copyright Text','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('fashion_designer_copyright_alingment',array(
        'default' => __('center','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control(new Fashion_Designer_Image_Radio_Control($wp_customize, 'fashion_designer_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','fashion-designer'),
        'section' => 'fashion_designer_footer',
        'settings' => 'fashion_designer_copyright_alingment',
        'choices' => array(
            'left' => get_template_directory_uri().'/assets/images/copyright1.png',
            'center' => get_template_directory_uri().'/assets/images/copyright2.png',
            'right' => get_template_directory_uri().'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting('fashion_designer_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('fashion_designer_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','fashion-designer'),
		'description'	=> __('Enter a value in pixels. Example:20px','fashion-designer'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'fashion-designer' ),
        ),
		'section'=> 'fashion_designer_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'fashion_designer_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'fashion_designer_switch_sanitization'
    ));  
    $wp_customize->add_control( new Fashion_Designer_Toggle_Switch_Custom_Control( $wp_customize, 'fashion_designer_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','fashion-designer' ),
      	'section' => 'fashion_designer_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'fashion_designer_scroll_to_top_icon', array( 
			'selector' => '.scrollup i', 
			'render_callback' => 'fashion_designer_customize_partial_fashion_designer_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('fashion_designer_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Fashion_Designer_Fontawesome_Icon_Chooser(
        $wp_customize,'fashion_designer_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','fashion-designer'),
		'transport' => 'refresh',
		'section'	=> 'fashion_designer_footer',
		'setting'	=> 'fashion_designer_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('fashion_designer_scroll_top_alignment',array(
        'default' => __('Right','fashion-designer'),
        'sanitize_callback' => 'fashion_designer_sanitize_choices'
	));
	$wp_customize->add_control(new Fashion_Designer_Image_Radio_Control($wp_customize, 'fashion_designer_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','fashion-designer'),
        'section' => 'fashion_designer_footer',
        'settings' => 'fashion_designer_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));

    // Has to be at the top
	$wp_customize->register_panel_type( 'Fashion_Designer_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'Fashion_Designer_WP_Customize_Section' );
}

add_action( 'customize_register', 'fashion_designer_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {

  class Fashion_Designer_WP_Customize_Panel extends WP_Customize_Panel {

    public $panel;
    public $type = 'fashion_designer_panel';
    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;
      return $array;
    }
  }
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  class Fashion_Designer_WP_Customize_Section extends WP_Customize_Section {
  	
    public $section;
    public $type = 'fashion_designer_section';
    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;

      if ( $this->panel ) {
        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
      } else {
        $array['customizeAction'] = 'Customizing';
      }
      return $array;
    }
  }
}

// Enqueue our scripts and styles
function fashion_designer_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'fashion_designer_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Fashion_Designer_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Fashion_Designer_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Fashion_Designer_Customize_Section_Pro( $manager,'example_1', array(
			'priority'   => 1,
			'title'    => esc_html__( 'Fashion Designer Pro', 'fashion-designer' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'fashion-designer' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/fashion-designer-wordpress-theme/'),
		)));

		$manager->add_section(new Fashion_Designer_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'fashion-designer' ),
			'pro_text' => esc_html__( 'DOCS', 'fashion-designer' ),
			'pro_url'  => admin_url('themes.php?page=fashion_designer_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'fashion-designer-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'fashion-designer-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Fashion_Designer_Customize::get_instance();